# LinkScrapper

### Usage:

After importing the package you should call 'getLinks(link)' and this will retrieve an array with all links
of the website you provied.

### This only works on https by the moment.


### Author: Augusto Cabrera
### BigEagle